# now no need to import like "import test_package.add import addition" directly we can import "from test_package import addition"
# add full import here and we can use shorthands while actually importing as package
from dummypackage12624.add import addition, subtraction, division
from dummypackage12624.custom_exception import InvalidUserInput